@@ -7,6 +7,7 @@ from time import time
 import mistune
 import os
 import re
+import urllib
 
 
 class LinkScraper(mistune.Renderer):
@@ -26,6 +27,21 @@ def find_links(text: str):
     return renderer.links
 
 
+def prompt_external_links():
+    selection = " "
+    # Repeat until the user enters a new line, Y or N.
+    while not re.fullmatch(r"([YyNn].*)?", selection):
+        print("Check for broken external links?")
+        selection = input(
+            "This will make HTTP requests to links in this project. [Y/n]: ")
+
+    # Check external links unless the user instructs us not to.
+    if not re.match(r"[Nn].*", selection):
+        return True
+    else:
+        return False
+
+
 class BrokenLinksPlugin(Plugin):
     name = "Broken Links"
     description = "Find all the broken links in your Lektor site!"
@@ -35,6 +51,15 @@ class BrokenLinksPlugin(Plugin):
         self.sources = []
         self.paths = []
 
+        self.check_external_links = False
+        try:
+            if os.environ["CHECK_EXT_LINKS"] == "1":
+                self.check_external_links = True
+            elif os.environ["CHECK_EXT_LINKS"] == "ask":
+                self.check_external_links = prompt_external_links()
+        except KeyError:
+            self.check_external_links = False
+
     def on_before_build_all(self, builder, **extra):
         self.sources = []
         self.paths = []
@@ -65,7 +90,11 @@ class BrokenLinksPlugin(Plugin):
                     style(f"Found {num_links} broken {link} in '{source.path}':", fg="red"))
 
                 for link in broken_links:
-                    print("    " + link)
+                    if link[1] is None and link[2] is None:
+                        print('    ' + link[0])
+                    else:
+                        print(
+                            '    ' + link[0] + ' ' + '(HTTP ' + str(link[1]) + ' ' + link[2] + ')')
 
         duration = time() - start_time
         print(style(f"Finished link check in {duration:.2} sec", fg="cyan"))
@@ -87,6 +116,22 @@ class BrokenLinksPlugin(Plugin):
                 dest = furl("/").join(dest)
 
                 if str(dest) not in self.paths:
-                    broken_links.append(link)
+                    broken_links.append([link, None, None])
+
+            # Find external HTTP links.
+            elif self.check_external_links and re.match(r'https?://.*', link):
+                status_code = 0
+                status_reason = ''
+
+                try:
+                    with urllib.request.urlopen(link) as response:
+                        status_code = response.status
+                        status_reason = response.reason
+                except urllib.error.HTTPError as error:
+                    status_code = error.code
+                    status_reason = error.reason
+
+                if status_code != 200:
+                    broken_links.append([link, status_code, status_reason])
 
         return broken_links
